mailr8137 - /1.3/prompt/spectrum.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by sebastien . morin . 1 on December 04, 2008 - 18:37:
Author: semor
Date: Thu Dec  4 18:37:04 2008
New Revision: 8137

URL: http://svn.gna.org/viewcvs/relax?rev=8137&view=rev
Log:
Modified the check for the spectrum_id being a string, a list is now accepted 
as well.

This is needed to implement the list of spectrum_id as in 
'test_suite/system_tests/peak_lists.py'
(test_read_peak_list_generic2() function).

Should the RelaxStrError be changed to something like a RelaxStrListError ?


Modified:
    1.3/prompt/spectrum.py

Modified: 1.3/prompt/spectrum.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/prompt/spectrum.py?rev=8137&r1=8136&r2=8137&view=diff
==============================================================================
--- 1.3/prompt/spectrum.py (original)
+++ 1.3/prompt/spectrum.py Thu Dec  4 18:37:04 2008
@@ -421,8 +421,8 @@
         if dir != None and type(dir) != str:
             raise RelaxNoneStrError, ('directory name', dir)
 
-        # The spectrum identification string.
-        if type(spectrum_id) != str:
+        # The spectrum identification string (or list).
+        if type(spectrum_id) != str and type(spectrum_id) != list:
             raise RelaxStrError, ('spectrum identification string', 
spectrum_id)
 
         # The heteronucleus name.




Related Messages


Powered by MHonArc, Updated Thu Dec 04 19:40:02 2008